.v-tooltip>.v-overlay__content{background:rgb(var(--v-theme-surface-variant));color:rgb(var(--v-theme-on-surface-variant));border-radius:4px;font-size:.875rem;line-height:1.6;display:inline-block;padding:5px 16px;text-transform:initial;width:auto;opacity:1;pointer-events:none;transition-property:opacity,transform;overflow-wrap:break-word}.v-tooltip>.v-overlay__content[class*=enter-active]{transition-timing-function:cubic-bezier(0,0,.2,1);transition-duration:.15s}.v-tooltip>.v-overlay__content[class*=leave-active]{transition-timing-function:cubic-bezier(.4,0,1,1);transition-duration:75ms}.list-item{padding:0 8px!important}.list-item>div.ListItem__prepend{padding-right:10px}.mediadetails-streamdetails{width:30px;height:14px;border-radius:2px;font-size:x-small;font-weight:800;min-width:55px;padding:0;box-shadow:none}.mediadetails-content-type-btn{height:25px!important;padding:7px!important;font-weight:500;font-size:10px!important;letter-spacing:.1em;border-radius:2px;margin:0}.streamdetails-item{height:50px;display:flex;align-items:center}@media (max-width: 400px){.streamdetails-item{font-size:.9rem}}@media (max-width: 370px){.streamdetails-item{font-size:.8rem}}.streamdetails-icon{height:30px;width:50px;contain:contain;object-fit:contain}.invert-on-light-mode{filter:none}.v-theme--light .invert-on-light-mode{filter:invert(100%)}.invert-on-dark-mode{filter:none}.v-theme--dark .invert-on-dark-mode{filter:invert(100%)}.streamdetails-separator{height:12.5px;display:flex;align-items:center;margin-top:12.5px;border-style:dotted;border-width:1px;border-bottom:none;border-left:none;border-right:none}.line-space{height:50px;width:16px}.line-space-halve{height:25px;width:16px}.line-start{border-top-left-radius:12.5px;height:25px;width:16px;margin-top:25px;margin-left:8px;border-width:1px;border-style:solid;border-bottom:none;border-right:none}.line-branch-start-left{height:25px;width:16px}.line-branch-start-left:before{content:"";height:14px;width:14px;border-width:1px;border-style:solid;border-bottom:none;border-right:none;margin-top:11px;border-top-left-radius:12px;margin-left:8px;position:absolute}.line-branch-start-right{height:25px;width:16px;margin-left:8px;border-left-width:1px;border-left-style:solid;border-top:none;border-right:none;border-bottom:none}.line-branch-start-right:before{content:"";height:12px;width:12px;border-width:1px;border-style:solid;border-left:none;border-top:none;border-bottom-right-radius:12px;transform:translate(-100%);position:absolute}.line-branch-split-left{height:25px;width:8px;border-style:solid;border-width:1px;border-right:none;border-top:none;border-bottom:none;margin-left:8px}.line-branch-split-left:before{content:"";height:12px;width:12px;border-width:1px;border-style:solid;border-top:none;border-right:none;border-bottom-left-radius:12px;position:absolute;transform:translate(-1px)}.line-branch-output{height:50px;width:16px;margin-left:8px;border-left-width:1px;border-left-style:solid;border-top:none;border-right:none;border-bottom:none}.line-branch-output:before{content:"";height:25px;width:16px;border-width:1px;border-style:solid;border-top:none;border-right:none;border-bottom-left-radius:12.5px;position:absolute;transform:translate(-1px)}.line-branch-end-left{height:25px;width:8px;margin-left:8px}.line-branch-end-left:before{content:"";height:12px;width:12px;border-width:1px;border-style:solid;border-top:none;border-right:none;border-bottom-left-radius:12px;position:absolute}.line-branch-rejoin-right{height:25px;width:8px;margin-left:8px}.line-branch-rejoin-right:before{content:"";height:14px;width:14px;border-width:1px;border-style:solid;border-bottom:none;border-left:none;margin-left:1px;margin-top:11px;border-top-right-radius:12px;position:absolute;transform:translate(-100%)}.line-end{border-bottom-left-radius:12.5px;height:25px;width:16px;margin-bottom:25px;margin-left:8px;border-width:1px;border-style:solid;border-top:none;border-right:none}.line-straight{height:50px;width:16px;margin-left:8px;border-left-width:1px;border-left-style:solid;border-top:none;border-right:none;border-bottom:none}.line-straight-halve{height:25px;width:16px;margin-left:8px;border-left-width:1px;border-left-style:solid;border-top:none;border-right:none;border-bottom:none}.line-with-dot{height:50px;width:16px;margin-left:8px;border-left-width:1px;border-left-style:solid;border-top:none;border-right:none;border-bottom:none;position:relative}.line-with-dot:before{content:"";position:absolute;transform:translate(-50%,-50%);margin-top:25px;height:14px;width:14px;background-color:rgba(var(--v-theme-on-surface));border-radius:50%}.line-with-dot:after{content:"";position:absolute;transform:translate(-50%,-50%);margin-top:25px;height:10px;width:10px;background-color:rgb(var(--v-theme-secondary));border-radius:50%}.quality-tier-dot{height:8px;width:8px;border-radius:50%;margin:auto 10px auto auto}.v-avatar.v-avatar--density-default[data-v-91021e25]{height:100%!important;width:100%!important}
