import{Q as p,c as u,a4 as n,Z as a,S as r,ao as o,R as l,ak as d,a0 as t,W as v}from"./index-orrnp8a1.js";const m=["title"],f=["innerHTML"],h=["title"],y=["innerHTML"],g=["title"],k=["innerHTML"],_=p({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean},monochrome:{type:Boolean}},setup(c){const s=c,i=u(()=>{if(s.domain in n.providers)return n.providers[s.domain].domain;if(s.domain in n.providerManifests)return s.domain});return(e,M)=>(r(),a("div",{style:o(`width:${e.size}px;margin-left:10px;margin-right:10px;content-align:center`)},[e.domain&&e.domain=="library"?(r(),l(d,{key:0,size:e.size,icon:"mdi-bookshelf",title:e.$t("item_in_library")},null,8,["size","title"])):s.monochrome&&i.value&&t(n).providerManifests[i.value].icon_svg_monochrome?(r(),a("div",{key:1,class:"d-flex align-center justify-center align-content-center justify-content-center",style:o(`width: ${e.size}px;height: ${e.size}px;${e.$vuetify.theme.current.dark?"":"filter: invert(1);"}`),title:t(n).providerManifests[i.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(n).providerManifests[i.value].icon_svg_monochrome},null,8,f)],12,m)):e.$vuetify.theme.current.dark&&i.value&&t(n).providerManifests[i.value].icon_svg_dark?(r(),a("div",{key:2,class:"d-flex align-center justify-center align-content-center justify-content-center",style:o(`width: ${e.size}px;height: ${e.size}px;`),title:t(n).providerManifests[i.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(n).providerManifests[i.value].icon_svg_dark},null,8,y)],12,h)):i.value&&t(n).providerManifests[i.value].icon_svg?(r(),a("div",{key:3,class:"d-flex align-center justify-center align-content-center justify-content-center",style:o(`width: ${e.size}px;height: ${e.size}px;`),title:t(n).providerManifests[i.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(n).providerManifests[i.value].icon_svg},null,8,k)],12,g)):i.value&&t(n).providerManifests[i.value].icon?(r(),l(d,{key:4,size:e.size,icon:"mdi-"+t(n).providerManifests[i.value].icon,title:t(n).providerManifests[i.value].name,dark:e.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(r(),l(d,{key:5,size:e.size,dark:e.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}});export{_};
