import{g as I,p as g,q as M,E as P,M as D,Q as S,aI as X,R as l,S as t,U as s,aH as Y,a7 as A,D as N,aw as V,a9 as r,B as f,W as w,b3 as O,bc as T,Z as k,a0 as h,a5 as $,aa as i,bt as H,bd as m,al as u,aZ as L,X as z,ap as E,a2 as F,bv as R,bu as Z,bo as j}from"./index-orrnp8a1.js";import{M as q}from"./MediaItemThumb-BFLLxiOJ.js";import{V as Q}from"./VCheckbox-BaanYS4J.js";import{a as U}from"./VBtn-BJolvyKt.js";import{_ as W}from"./_plugin-vue_export-helper-DlAUqK2U.js";const G=g({disabled:Boolean,modelValue:{type:Boolean,default:null},...D()},"VHover"),J=I()({name:"VHover",props:G(),emits:{"update:modelValue":o=>!0},setup(o,y){let{slots:a}=y;const d=M(o,"modelValue"),{runOpenDelay:p,runCloseDelay:v}=P(o,n=>!o.disabled&&(d.value=n));return()=>{var n;return(n=a.default)==null?void 0:n.call(a,{isHovering:d.value,props:{onMouseenter:p,onMouseleave:v}})}}}),K=["model-value"],_={key:0},x={key:1},ee={key:2},ae=S({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0},parentItem:{default:void 0}},emits:["select"],setup(o,{emit:y}){const a=o,d=y,p=function(e){if(a.showCheckboxes)return;const C="clientX"in e?e.clientX:e.touches[0].clientX,b="clientY"in e?e.clientY:e.touches[0].clientY;Z(a.item,C,b,a.parentItem)},v=function(e){if(a.showCheckboxes){d("select",a.item,!a.isSelected);return}R(a.item,e.clientX,e.clientY,a.parentItem)},n=function(e){a.showCheckboxes||j(a.item,e.clientX,e.clientY,a.parentItem)};return(e,C)=>{const b=X("hold");return t(),l(J,null,{default:s(({isHovering:c,props:B})=>[Y((t(),l(A,N(B,{class:{"on-hover":c,unavailable:!e.isAvailable},elevation:c?3:0,onClick:v,onContextmenu:V(p,["right","prevent"])}),{default:s(()=>[e.showCheckboxes?(t(),l(O,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:s(()=>[f(Q,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):r("",!0),f(q,{item:e.isAvailable?e.item:void 0},null,8,["item"]),w("div",{class:E(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":c||e.$vuetify.display.mobile||e.permanentOverlay},[f(z,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:s(()=>[f(T,null,{default:s(()=>[e.item.media_type==h($).FOLDER?(t(),k("span",_,[w("span",null,i(h(H)(e.item,e.$t)),1)])):(t(),k("span",x,i(e.item.name),1)),"version"in e.item&&e.item.version?(t(),k("span",ee," - "+i(e.item.version),1)):r("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(t(),l(m,{key:0,class:"line-clamp-1"},{default:s(()=>[u(i(h(L)(e.item.artists,1)),1)]),_:1})):r("",!0),"authors"in e.item&&e.item.authors?(t(),l(m,{key:1,class:"line-clamp-1"},{default:s(()=>[u(i(e.item.authors.join(" / ")),1)]),_:1})):"publisher"in e.item&&e.item.publisher?(t(),l(m,{key:2,class:"line-clamp-1"},{default:s(()=>[u(i(e.item.publisher),1)]),_:1})):"owner"in e.item&&e.item.owner?(t(),l(m,{key:3,class:"line-clamp-1"},{default:s(()=>[u(i(e.item.owner),1)]),_:1})):"provider_mappings"in e.item?r("",!0):(t(),l(m,{key:4,class:"line-clamp-1"},{default:s(()=>[u(i(e.$t(e.item.media_type)),1)]),_:1}))]),_:1})],10,K),(c||h(F).isTouchscreen)&&e.isAvailable&&e.item.is_playable?(t(),l(U,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:V(n,["stop"])})):r("",!0)]),_:2},1040,["class","elevation"])),[[b,p]])]),_:1})}}}),ne=W(ae,[["__scopeId","data-v-aed809e3"]]);export{ne as P,J as V};
