/* empty css              */import{g as o,p as r,f as i,ac as l,A as m,I as c,ad as u,N as d,B as p}from"./index-orrnp8a1.js";const f=r({fluid:{type:Boolean,default:!1},...d(),...u(),...c()},"VContainer"),y=o()({name:"VContainer",props:f(),setup(e,s){let{slots:a}=s;const{rtlClasses:n}=i(),{dimensionStyles:t}=l(e);return m(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},n.value,e.class],style:[t.value,e.style]},a)),{}}});export{y as V};
