import{u as A,V as t,a as l,m as I,b as B}from"./VCheckboxBtn-CICj8ZxL.js";import{g as F,p as U,q as D,bI as R,c as q,A as M,c2 as N,B as u,D as r,aC as $}from"./index-orrnp8a1.js";const j=U({...I(),...$(B(),["inline"])},"VCheckbox"),E=F()({name:"VCheckbox",inheritAttrs:!1,props:j(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,c){let{attrs:d,slots:a}=c;const s=D(e,"modelValue"),{isFocused:n,focus:i,blur:m}=A(e),V=R(),b=q(()=>e.id||`checkbox-${V}`);return M(()=>{const[p,v]=N(d),f=t.filterProps(e),k=l.filterProps(e);return u(t,r({class:["v-checkbox",e.class]},p,f,{modelValue:s.value,"onUpdate:modelValue":o=>s.value=o,id:b.value,focused:n.value,style:e.style}),{...a,default:o=>{let{id:x,messagesId:h,isDisabled:P,isReadonly:C,isValid:y}=o;return u(l,r(k,{id:x.value,"aria-describedby":h.value,disabled:P.value,readonly:C.value},v,{error:y.value===!1,modelValue:s.value,"onUpdate:modelValue":g=>s.value=g,onFocus:i,onBlur:m}),a)}})}),{}}});export{E as V};
