import{c as r,aR as c,R as i,S as u,aq as d,$ as p,D as f,U as v,ar as _}from"./index-orrnp8a1.js";import{_ as m}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{V as $}from"./VContainer-DvR1uhzJ.js";const h={props:{variant:{type:String,default:"default",validator:a=>["default","panel"].includes(a)}},setup(a,n){const t=r(()=>({class:"container-default"})),e=r(()=>({class:c.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(a.variant){case"default":return t.value;case"panel":return e.value;default:return t.value}})}}};function P(a,n,t,e,o,l){return u(),i($,f(e.btnProps,{variant:"default",fluid:""}),d({_:2},[p(a.$slots,(k,s)=>({name:s,fn:v(()=>[_(a.$slots,s,{},void 0,!0)])}))]),1040)}const V=m(h,[["render",P],["__scopeId","data-v-de1efc7e"]]);export{V as C};
