import{Q as w,o as f,R as n,S as t,af as c,a0 as a,aj as g,ba as _,U as o,ar as y,Z as l,B as p,ao as v,W as R,aa as d,ak as h,al as b,G as k,$ as V,bb as $,a5 as m}from"./index-orrnp8a1.js";import{P as B}from"./PanelviewItemCompact-Bf1Qb2IB.js";import{V as C}from"./VToolbar-BlKUHnwt.js";import{V as A}from"./Toolbar-CE2HDv9i.js";import{V as I}from"./VAlert-BhQ3L7Kc.js";import{_ as T}from"./_plugin-vue_export-helper-DlAUqK2U.js";const S=w({__name:"Carousel",setup(u){return f(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(e,r)=>{const i=c("swiper");return t(),n(i,{"slides-per-view":a(_)(e.$vuetify.display.width)+.5,"space-between":24,"free-mode":!0,navigation:!a(g)({breakpoint:"mobile"}),mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:o(()=>[y(e.$slots,"default")]),_:3},8,["slides-per-view","navigation"])}}}),E={class:"widget-row"},H={class:"mr-3"},M={key:1,class:"mr-3"},N=w({__name:"HomeWidgetRow",props:{widgetRow:{}},setup(u){return(e,r)=>{const i=c("swiper-slide");return t(),l("div",E,[p(C,{class:"header",color:"transparent",style:v(e.widgetRow.path?"cursor: pointer; width: fit-content;":"width: fit-content;"),onClick:r[0]||(r[0]=s=>e.widgetRow.path?e.$router.push(e.widgetRow.path):"")},{prepend:o(()=>[p(h,{icon:e.widgetRow.icon},null,8,["icon"])]),title:o(()=>[e.widgetRow.count?(t(),n(A,{key:0,inline:"",color:"grey",content:e.widgetRow.count},{default:o(()=>[R("span",H,d(e.$t(e.widgetRow.label)),1)]),_:1},8,["content"])):(t(),l("span",M,d(e.$t(e.widgetRow.label)),1))]),_:1},8,["style"]),e.widgetRow.items.length==0?(t(),n(I,{key:0},{default:o(()=>[b(d(e.$t("no_content")),1)]),_:1})):(t(),n(S,{key:1},{default:o(()=>[(t(!0),l(k,null,V(e.widgetRow.items,s=>(t(),n(i,{key:s.uri},{default:o(()=>[p(B,{item:s,"permanent-overlay":![a(m).ALBUM,a(m).TRACK,a(m).RADIO].includes(s.media_type),"is-available":a($)(s)},null,8,["item","permanent-overlay","is-available"])]),_:2},1024))),128))]),_:1}))])}}}),j=T(N,[["__scopeId","data-v-ec2c4544"]]);export{j as H};
