.container-default[data-v-de1efc7e]{padding:10px}.container-panels-light[data-v-de1efc7e]{background:#f5f5f5}@media (min-width: 1920px){.container-default[data-v-de1efc7e]{max-width:unset!important}}@media (min-width: 1280px){.container-default[data-v-de1efc7e]{max-width:unset!important}}@media (min-width: 960px){.container[data-v-de1efc7e]{max-width:unset!important}}
