import{c as r,R as u,S as c,aq as $,$ as w,U as d,ar as m,D as B,af as h,aI as I,aH as M,a9 as P,aw as f,X as _}from"./index-orrnp8a1.js";import{_ as b}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{a as y}from"./VBtn-BJolvyKt.js";const k={props:{variant:{type:String,default:"default",validator:t=>["plain","default","responsive","icon","list"].includes(t)}},setup(t,s){const e={},o=r(()=>({...e,class:"v-btn--variant-responsive",ripple:!0,icon:!0,style:"height: min(calc(100vw - 40px), calc(100vh - 340px)); width: min(calc(100vw - 40px), calc(100vh - 340px));"})),i=r(()=>({...e,ripple:!1})),l=r(()=>({...e,density:"comfortable"}));return{btnProps:r(()=>{switch(t.variant){case"default":return e;case"plain":return e;case"responsive":return o.value;case"icon":return i.value;case"list":return l.value;default:return e}})}}};function C(t,s,e,o,i,l){return c(),u(y,B(o.btnProps,{variant:"plain"}),$({_:2},[w(t.$slots,(p,a)=>({name:a,fn:d(()=>[m(t.$slots,a)])}))]),1040)}const D=b(k,[["render",C]]),L={components:{MAButton:D},props:{showMenuBtn:{type:Boolean,default:!1}},setup(t,s){const e=r(()=>({}));return{listItemProps:r(()=>({...e.value,...s.attrs}))}}};function V(t,s,e,o,i,l){const p=h("MAButton"),a=I("hold");return M((c(),u(_,B(o.listItemProps,{class:"list-item-main",onInput:s[1]||(s[1]=n=>t.$emit("input",n)),onContextmenu:s[2]||(s[2]=f(n=>t.$emit("menu",n),["right","prevent"]))}),$({_:2},[w(t.$slots,(n,v)=>({name:v,fn:d(()=>[m(t.$slots,v,{},void 0,!0)])})),t.$slots.append||e.showMenuBtn?{name:"append",fn:d(()=>[m(t.$slots,"append",{},void 0,!0),e.showMenuBtn?(c(),u(p,{key:0,variant:"list",icon:"mdi-dots-vertical",onClick:s[0]||(s[0]=f(n=>t.$emit("menu",n),["stop"]))})):P("",!0)]),key:"0"}:void 0]),1040)),[[a,n=>t.$emit("menu",n)]])}const R=b(L,[["render",V],["__scopeId","data-v-22bb765c"]]);export{D as B,R as L};
