import{Q as u,c as l,bn as c,Z as p,B as i,W as m,Y as d,U as v,af as g,S as a,R as f,ae as b}from"./index-orrnp8a1.js";import{T as h}from"./Toolbar-CE2HDv9i.js";import"./VToolbar-BlKUHnwt.js";import"./VBtn-BJolvyKt.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";const k=u({__name:"Settings",setup(y){const o=c(),n=l(()=>{var e,t,r;return(e=o.currentRoute.value.name)!=null&&e.toString().includes("player")?"players":(t=o.currentRoute.value.name)!=null&&t.toString().includes("core")?"core":(r=o.currentRoute.value.name)!=null&&r.toString().includes("frontend")?"frontend":"providers"});return(e,t)=>{const r=g("router-view");return a(),p("div",null,[i(h,{icon:"mdi-cog-outline",title:e.$t("settings.settings"),"show-loading":!0,"menu-items":[{label:"settings.providers",icon:"mdi-apps",action:()=>{e.$router.push({name:"providersettings"})},active:n.value=="providers"},{label:"settings.players",icon:"mdi-speaker-multiple",action:()=>{e.$router.push({name:"playersettings"})},active:n.value=="players"},{label:"settings.core",icon:"mdi-engine",action:()=>{e.$router.push({name:"coresettings"})},active:n.value=="core"},{label:"settings.frontend",icon:"mdi-palette-advanced",action:()=>{e.$router.push({name:"frontendsettings"})},active:n.value=="frontend"}]},null,8,["title","menu-items"]),i(d),t[0]||(t[0]=m("div",{style:{height:"15px"}},null,-1)),i(r,{app:""},{default:v(({Component:s})=>[(a(),f(b(s)))]),_:1})])}}});export{k as default};
